Learn R Programming

metan (version 1.17.0)

set_wd_here: Set the Working Directory quicky

Description

[Experimental] It sets the working directory to the path of the current script.

Usage

set_wd_here(path = NULL)

Value

A message showing the current working directory

Arguments

path

Path components below the project root. Defaults to NULL. This means that the directory will be set to the path of the file. If the path doesn't exist, the user will be asked if he wants to create such a folder.

Examples

Run this code

if (FALSE) {
set_wd_here()
}

Run the code above in your browser using DataLab